# Python Primer Design Library

[![CI](https://github.com/fulcrumgenomics/prymer/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/fulcrumgenomics/prymer/actions/workflows/tests.yml?query=branch%3Amain)
[![Python Versions](https://img.shields.io/badge/python-3.11_|_3.12-blue)](https://github.com/fulcrumgenomics/prymer)
[![MyPy Checked](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://docs.astral.sh/ruff/)
[![codecov](https://codecov.io/github/fulcrumgenomics/prymer/graph/badge.svg?token=wuTCpNGVaP)](https://codecov.io/github/fulcrumgenomics/prymer)

## Quick setup

See [Installation](docs/installation.md).

